@@ -13,6 +13,9 @@
 #' @param startdate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA. [character]
 #' @param enddate Either NA, meaning all available dates, or a character vector in the form YYYY-MM, e.g. 2017-01. Defaults to NA. [character]
 #' @param pubdate The maximum publication date of data to include in stacking, in the form YYYY-MM-DD. If NA, the most recently published data for each product-site-month combination will be selected. Otherwise, the most recent publication date that is older than pubdate will be selected. Thus the data stacked will be the data that would have been accessed on the NEON Data Portal, if it had been downloaded on pubdate. [character]
+#' @param timeIndex Either the string 'all', or the time index of data to be stacked, in minutes. Only applicable to sensor (IS) and eddy covariance data. Defaults to 'all'. [character]
+#' @param level Data product level of data to stack. Only applicable to eddy covariance (SAE) data; see stackEddy() documentation. [character]
+#' @param var Variables to be extracted and stacked from H5 files. Only applicable to eddy covariance (SAE) data; see stackEddy() documentation. [character]
 #' @param zipped Should stacking use data from zipped files or unzipped folders? This option allows zips and their equivalent unzipped folders to be stored in the same directory; stacking will extract whichever is specified. Defaults to FALSE, i.e. stacking using unzipped folders. [logical]
 #' @param package Either "basic" or "expanded", indicating which data package to stack. Defaults to basic. [character]
 #' @param load If TRUE, stacked data are read into the current R environment. If FALSE, stacked data are written to the directory where data files are stored. Defaults to TRUE. [logical]
@@ -30,9 +33,10 @@
 ##############################################################################################
 stackFromStore <- function(filepaths, dpID, site="all", 
                            startdate=NA, enddate=NA, 
-                           pubdate=NA, zipped=FALSE,
-                           package="basic", load=TRUE, 
-                           nCores=1) {
+                           pubdate=NA, timeIndex="all",
+                           level="dp04", var=NA,
+                           zipped=FALSE, package="basic", 
+                           load=TRUE, nCores=1) {
   
   if(any(!file.exists(filepaths))) {
     stop("Files not found in specified file paths.")
@@ -88,7 +92,12 @@ stackFromStore <- function(filepaths, dpID, site="all",
       if(load==FALSE) {
         stop("Writing to local directory is not available for DP4.00200.001. Use load=TRUE and assign to a variable name.")
       } else {
-        return(stackEddy(filepaths))
+        if(timeIndex=="all") {
+          avg <- NA
+        } else {
+          avg <- timeIndex
+        }
+        return(stackEddy(filepath=filepaths, level=level, avg=avg, var=var))
       }
     } else {
       if(load==TRUE) {
@@ -108,7 +117,7 @@ stackFromStore <- function(filepaths, dpID, site="all",
     
     if(zipped==T) {
       files <- files[grep(".zip$", files)]
-      stop("Files must be unzipped to use this function. Zip file handling will be added in a future version.")
+      stop("Files must be unzipped to use this function. Zip file handling may be added in a future version.")
     } else {
       files <- files[grep(".zip$", files, invert=T)]
     }
@@ -117,6 +126,11 @@ stackFromStore <- function(filepaths, dpID, site="all",
       files <- files[grep(paste(site, collapse="|"), files)]
     }
     
+    # check for no files
+    if(length(files)==0) {
+      stop("No files found meeting all input criteria.")
+    }
+    
     # basic vs expanded files are simple for SAE, not for everything else
     if(dpID=="DP4.00200.001") {
       files <- files[grep(package, files)]
@@ -287,6 +301,31 @@ stackFromStore <- function(filepaths, dpID, site="all",
       
     }
     
+    # filter by time interval
+    if(timeIndex!="all" & dpID!="DP4.00200.001") {
+      
+      if(all(table_types$tableTMI[which(table_types$productID==dpID)]==0)) {
+        stop(paste("timeIndex is only a valid input for sensor data. ", dpID, 
+                   " is not a time-aggregated product.", sep=""))
+      }
+      
+      if(!timeIndex %in% table_types$tableTMI[which(table_types$productID==dpID)]) {
+        stop(paste(timeIndex, " is not a valid time interval for ", dpID,
+                   ". Use function getTimeIndex() to find valid time intervals.", sep=""))
+      }
+      
+      # drop files with minutes in the name, that aren't the correct number of minutes
+      # do it this way, instead of selecting only the correct number of minutes,
+      # to keep all the metadata files
+      tabInd <- grep("min", files, fixed=T)
+      timeInd <- union(grep(paste(timeIndex, "min", sep=""), files, fixed=T),
+                       grep(paste(timeIndex, "_min", sep=""), files, fixed=T))
+      dropInd <- setdiff(tabInd, timeInd)
+      
+      files <- files[-dropInd]
+      
+    }
+    
     # check for no files
     if(length(files)==0) {
       stop("No files found meeting all input criteria.")
@@ -296,7 +335,12 @@ stackFromStore <- function(filepaths, dpID, site="all",
       if(load==FALSE) {
         stop("Writing to local directory is not available for DP4.00200.001. Use load=TRUE and assign to a variable name.")
       } else {
-        return(stackEddy(files))
+        if(timeIndex=="all") {
+          avg <- NA
+        } else {
+          avg <- timeIndex
+        }
+        return(stackEddy(filepath=files, level=level, avg=avg, var=var))
       }
     } else {
       if(load==TRUE) {
